@@ -1,11 +1,3 @@
-# Business::Shipping::Config - Configuration functions
-# 
-# $Id: Config.pm 184 2004-09-17 02:34:19Z db-ship $
-# 
-# Copyright (c) 2003-2004 Kavod Technologies, Dan Browning. All rights reserved.
-# This program is free software; you may redistribute it and/or modify it under
-# the same terms as Perl itself. See LICENSE for more info.
-
 package Business::Shipping::Config;
 
 =head1 NAME
@@ -14,23 +6,21 @@ Business::Shipping::Config - Configuration functions
 
 =head1 VERSION
 
-$Rev: 184 $      $Date: 2004-09-16 19:34:19 -0700 (Thu, 16 Sep 2004) $
+$Rev: 189 $
 
 =head1 DESCRIPTION
 
-Business::Shipping::Config is currently just a simple API on top of the 
+Among other things, this module implements a simple API on top of the 
 Config::IniFiles module.
 
 =head1 METHODS
 
-=over 4
-
 =cut
 
 use constant DEFAULT_SUPPORT_FILES_DIR => '/var/perl/Business-Shipping';
 #use constant DEFAULT_SUPPORT_FILES_DIR => '~_~SUPPORT_FILES_DIR~_~';
 
-$VERSION = do { my $r = q$Rev: 184 $; $r =~ /\d+/; $&; };
+$VERSION = do { my $r = q$Rev: 189 $; $r =~ /\d+/; $&; };
 @EXPORT = qw/ cfg cfg_obj config_to_hash config_to_ary_of_hashes /;
 
 use strict;
@@ -70,11 +60,25 @@ $Business::Shipping::Config::Try_Limit = 2;
 tie my %cfg, 'Config::IniFiles', (      -file => $main_config_file );
 my $cfg_obj = Config::IniFiles->new(    -file => $main_config_file );
 
+=head2 cfg()
+
+Returns config hashref.
+
+=head2 cfg_obj()
+
+Returns config hashref.
+
+=head2 support_files()
+
+Returns the path of the support_files directory.
+
+=cut
+
 sub cfg             { return \%cfg;                 }
 sub cfg_obj         { return $cfg_obj;              }
 sub support_files   { return $support_files_dir;    }
 
-=item * config_to_hash( $ary, $del )
+=head2 config_to_hash( $ary, $del )
 
  $ary   Key/value pairs
  $del   Delimiter for the above array (tab is default)
@@ -103,7 +107,7 @@ sub config_to_hash
     return $hash;    
 }
 
-=item * config_to_ary_of_hashes( 'configuration_parameter' )
+=head2 config_to_ary_of_hashes( 'configuration_parameter' )
 
 Reads in the configuration hashref ( e.g. cfg()->{ primary }->{ secondary } ),
 then returns an array of hashes.  For example:
@@ -169,12 +173,24 @@ sub config_to_ary_of_hashes
     return @ary;
 }
 
+=head2 data_dir_name()
+
+The name of the data_dir (e.g. "data").
+
+=cut
+
 sub data_dir_name
 {
     # name only.
     return cfg()->{ general }->{ data_dir_name } || 'data';
 }
 
+=head2 data_dir()
+
+The path of the data_dir (e.g. "/var/perl/Business-Shipping/data").
+
+=cut
+
 sub data_dir
 {
     # full path.  combine with support files dir if applicable.
@@ -197,12 +213,132 @@ sub data_dir
     }
 }
 
+=head2 get_req_mod()
+
+Return a list of the required modules for a given shipper.  Return all if no
+shipper is given.
+
+=cut
+
+sub get_req_mod
+{
+    my ( %opt ) = @_;
+    my $shipper = $opt{ shipper };
+    
+    my $req_mod = {
+        'Minimum' => [ qw/
+            Scalar::Util
+            Class::MethodMaker::Engine              
+            Log::Log4perl                           
+            Business::Shipping                      
+            /
+        ],
+        'UPS_Offline' => [ qw/
+            Bundle::DBD::CSV                        
+            Business::Shipping::DataFiles           
+            Config::IniFiles                        
+            Math::BaseCnv                           
+            /
+        ],
+        'UPS_Online' => [ qw/
+            Cache::FileCache
+            Clone
+            Crypt::SSLeay
+            LWP::UserAgent
+            XML::DOM
+            XML::Simple
+            / 
+        ],
+        'USPS_Online' => [ qw/
+            Cache::FileCache
+            Clone
+            Crypt::SSLeay
+            LWP::UserAgent
+            XML::DOM
+            XML::Simple
+            /
+        ],
+            
+    };
+    if ( $opt{ get_hash } ) {
+        return $req_mod;
+    }
+    if ( $shipper ) {
+        my $module_list = $req_mod->{ $shipper };
+        return @$module_list;
+    }
+    else {
+        my @all_modules;
+        foreach my $key ( keys %$req_mod ) {
+            my $module_list = $req_mod->{ $shipper };
+            push @all_modules, @$module_list;
+        }
+        return @all_modules;
+    }
+}
+
+=head2 calc_req_mod()
+
+Determine if the required modules for each shipper are available, in turn.
+
+=cut
+
+sub calc_req_mod
+{
+    my ( $one_shipper ) = @_;
+    
+    my @avail;
+    my $req_mod = get_req_mod( get_hash => 1 );
+    
+
+    if ( $one_shipper ) {
+        foreach my $shipper ( keys %$req_mod ) {
+            if ( $shipper ne $one_shipper ) {
+                delete $req_mod->{ $shipper };
+            }
+        }
+    }
+    my @to_load;
+    SHIPPER: while ( my ( $shipper, $list ) = each %$req_mod ) {
+        @to_load = ();
+        MODULE: foreach my $module ( @$list ) {
+            eval "use $module";
+            if ( $@ ) {
+                $@ = '';
+                # "Could not load $module";
+                next SHIPPER;
+            }
+            else {
+                push @to_load, $module;
+                next MODULE;
+            }
+        }
+        if ( ! $@ ) {
+            push @avail, $shipper;
+            foreach my $module ( @to_load ) {
+                #if ( $to_load_ver ) 
+                #    { use_ok( $to_load_mod => $to_load_ver ); }
+                #else 
+                #    { use_ok( $to_load_mod ); }
+            }
+        }
+    }
+    if ( $one_shipper ) {
+        if ( grep $one_shipper, @avail ) {
+            return 1;
+        }
+        else {
+            return 0;
+        }
+    }
+    else {
+        return @avail;
+    }
+}
 1;
 
 __END__
 
-=back
-
 =head1 AUTHOR
 
 Dan Browning E<lt>F<db@kavod.com>E<gt>, Kavod Technologies, L<http://www.kavod.com>.
