@@ -1,6 +1,6 @@
 # Business::Shipping::Tracking - Abstract class
 # 
-# $Id: Tracking.pm 169 2004-09-14 19:02:28Z db-ship $
+# $Id: Tracking.pm 190 2004-09-19 04:29:09Z db-ship $
 # 
 # Copyright (c) 2004 Infogears Inc.  All rights reserved.
 # Portions Copyright (c) 2003-2004 Kavod Technologies, Dan Browning. All rights 
@@ -13,7 +13,7 @@ package Business::Shipping::Tracking;
 
 =head1 NAME
 
-Business::Shipping::Tracking - API for tracking packages
+Business::Shipping::Tracking
 
 =head1 SYNOPSIS
 
@@ -44,7 +44,7 @@ Business::Tracking is an API for tracking shipments
 =cut
 
 
-$VERSION = do { my $r = q$Rev: 169 $; $r =~ /\d+/; $&; };
+$VERSION = do { my $r = q$Rev: 190 $; $r =~ /\d+/; $&; };
 
 use strict;
 use warnings;
