@@ -1,9 +1,8 @@
+# TODO: Implement USPS_Offline.  This is just a place-holder.
 #
-# TODO: Implement Offline::USPS.  This is just a place-holder.
+# Business::Shipping::USPS_Offline::RateRequest
 #
-# Business::Shipping::RateRequest::Offline::USPS
-#
-# $Id: RateRequest.pm 164 2004-09-14 00:12:54Z db-ship $
+# $Id: RateRequest.pm 190 2004-09-19 04:29:09Z db-ship $
 #
 # Copyright (C) 2003 Interchange Development Group
 # Copyright (c) 2003, 2004 Kavod Technologies, Dan Browning. 
@@ -14,13 +13,12 @@
 # 
 # Based on the corresponding work in the Interchange project, which was written 
 # by Mike Heins <mike@perusion.com>. See http://www.icdevgroup.org for more info.
-#
 
-package Business::Shipping::RateRequest::Offline::USPS;
+package Business::Shipping::USPS_Offline::RateRequest;
 
 =head1 NAME
 
-Business::Shipping::RateRequest::Offline::USPS -- Calculates US Postal service rates (intl only)
+Business::Shipping::USPS_Offline::RateRequest - Rates
 
 =head1 SYNOPSIS
 
@@ -78,7 +76,7 @@ multiple 70-pound packages (plus one package with the remainder).
 
 =cut
 
-$VERSION = do { my $r = q$Rev: 164 $; $r =~ /\d+/; $&; };
+$VERSION = do { my $r = q$Rev: 190 $; $r =~ /\d+/; $&; };
 
 use strict;
 use warnings;
@@ -236,8 +234,9 @@ Dan Browning E<lt>F<db@kavod.com>E<gt>, Kavod Technologies, L<http://www.kavod.c
 
 =head1 COPYRIGHT AND LICENCE
 
-Copyright (c) 2003-2004 Kavod Technologies, Dan Browning. All rights reserved.
-This program is free software; you may redistribute it and/or modify it under
-the same terms as Perl itself. See LICENSE for more info.
+Copyright (c) 2003-2004 Kavod Technologies, Dan Browning, Interchange 
+Development Group. All rights reserved.
+
+Licensed under the GNU Public Licnese (GPL).  See LICENSE for more info.
 
 =cut
